BaseBufferAttribute<TData extends TypedDataList> class abstract

Implementers

Constructors

BaseBufferAttribute()

Properties

array ↔ TData
getter/setter pair
buffer ↔ int?
getter/setter pair
count ↔ int
getter/setter pair
data ↔ InterleavedBuffer?
getter/setter pair
elementSize ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemSize ↔ int
getter/setter pair
name ↔ String?
getter/setter pair
normalized ↔ bool
getter/setter pair
onUploadCallback ↔ void Function()?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair
updateRange ↔ Map<String, int>?
getter/setter pair
usage ↔ int
getter/setter pair
version ↔ int
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited