InstancedInterleavedBuffer class

An instanced version of InterleavedBuffer.

Inheritance

Constructors

InstancedInterleavedBuffer(TypedDataList array, int stride, dynamic meshPerAttribute)

Properties

array ↔ TypedDataList
getter/setter pairinherited
count ↔ int
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isInstancedInterleavedBuffer ↔ bool
getter/setter pair
isInterleavedBuffer ↔ bool
getter/setter pairinherited
itemSize ↔ int
getter/setter pairinherited
meshPerAttribute ↔ int
getter/setter pairinherited
needsUpdate ← bool
no getterinherited
onUploadCallback ↔ Function?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stride ↔ int
getter/setter pairinherited
type ↔ String
getter/setter pairinherited
updateRanges ↔ List
getter/setter pairinherited
usage ↔ int
getter/setter pairinherited
uuid ↔ String
getter/setter pairinherited
version ↔ int
getter/setter pairinherited

Methods

addUpdateRange(int start, int count) → void
inherited
clearUpdateRanges() → void
Clears the update ranges.
inherited
clone([Map<String, dynamic>? data]) → InstancedInterleavedBuffer
data - This object holds shared array buffers required for properly cloning geometries with interleaved attributes.
override
copy(InterleavedBuffer source) → InstancedInterleavedBuffer
Copies another source to this source.
override
copyAt(int index1, InterleavedBuffer attribute, int index2) → InterleavedBuffer
Copies data from attribute[index2] to arrayindex1.
inherited
dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUpload(Function callback) → InterleavedBuffer
inherited
setUsage(int value) → InterleavedBuffer
inherited
toJson(InterleavedBuffer data) → Map<String, dynamic>
data - This object holds shared array buffers required for properly serializing geometries with interleaved attributes.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited