InterleavedBuffer class

Interleaved means that multiple attributes, possibly of different types, (e.g., position, normal, uv, color) are packed into a single array buffer.

An introduction into interleaved arrays can be found here: Interleaved array basics

Implementers

Constructors

InterleavedBuffer(TypedDataList array, int stride)
array -- A typed array with a shared buffer. Stores the geometry data.
InterleavedBuffer.fromList(TypedData array, int stride)
array -- A typed array with a shared buffer. Stores the geometry data.
factory

Properties

array ↔ TypedDataList
getter/setter pair
count ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isInterleavedBuffer ↔ bool
getter/setter pair
itemSize ↔ int
getter/setter pair
meshPerAttribute ↔ int
getter/setter pair
needsUpdate ← bool
no getter
onUploadCallback ↔ Function?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stride ↔ int
getter/setter pair
type ↔ String
getter/setter pair
updateRanges ↔ List
getter/setter pair
usage ↔ int
getter/setter pair
uuid ↔ String
getter/setter pair
version ↔ int
getter/setter pair

Methods

addUpdateRange(int start, int count) → void
clearUpdateRanges() → void
Clears the update ranges.
clone([Map<String, dynamic>? data]) → InterleavedBuffer
data - This object holds shared array buffers required for properly cloning geometries with interleaved attributes.
copy(InterleavedBuffer source) → InterleavedBuffer
Copies another source to this source.
copyAt(int index1, InterleavedBuffer attribute, int index2) → InterleavedBuffer
Copies data from attribute[index2] to arrayindex1.
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUpload(Function callback) → InterleavedBuffer
setUsage(int value) → InterleavedBuffer
toJson(InterleavedBuffer data) → Map<String, dynamic>
data - This object holds shared array buffers required for properly serializing geometries with interleaved attributes.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited