InterleavedBufferAttribute class

Inheritance

Constructors

InterleavedBufferAttribute(InterleavedBuffer? data, int itemSize, int offset, [bool _normalized = false])

Properties

array ↔ TypedDataList
getter/setter pairinherited-setteroverride-getter
buffer ↔ int?
getter/setter pairinherited
count ↔ int
getter/setter pairinherited-setteroverride-getter
data ↔ InterleavedBuffer?
getter/setter pairoverride
elementSize ↔ int?
getter/setter pairinherited
gpuType ↔ int
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isBufferAttribute ↔ bool
getter/setter pairinherited
itemSize ↔ int
getter/setter pairoverride
length → int
no setterinherited
name ↔ String?
getter/setter pairoverride
needsUpdate ← bool
no getteroverride
normalized ↔ bool
getter/setter pairoverride
offset ↔ int
getter/setter pair
onUploadCallback ↔ void Function()?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pairoverride
updateRange ↔ Map<String, int>?
getter/setter pairinherited
updateRanges ↔ List<Ranges>
getter/setter pairinherited
usage ↔ int
getter/setter pairinherited
version ↔ int
getter/setter pairinherited

Methods

addUpdateRange(int start, int count) → void
inherited
applyMatrix3(Matrix3 m) → BufferAttribute<TypedDataList>
Applies matrix m to every Vector3 element of this BufferAttribute.
inherited
applyMatrix4(Matrix4 m) → InterleavedBufferAttribute
Applies matrix m to every Vector3 element of this BufferAttribute.
override
applyNormalMatrix(Matrix3 m) → InterleavedBufferAttribute
Applies normal matrix m to every Vector3 element of this InterleavedBufferAttribute.
override
clearUpdateRanges() → void
inherited
clone([Map<String, dynamic>? data]) → BufferAttribute<TypedDataList>
Return a copy of this bufferAttribute.
override
copy(BufferAttribute<TypedDataList> source) → BufferAttribute<TypedDataList>
Copies another BufferAttribute to this BufferAttribute.
inherited
copyArray(TypedDataList array) → BufferAttribute<TypedDataList>
Copy the array given here (which can be a normal array or TypedArray) into array.
inherited
copyAt(int index1, BufferAttribute<TypedDataList> attribute, int index2) → BufferAttribute<TypedDataList>
Copy a vector from bufferAttributeindex2 to arrayindex1.
inherited
copyColorsArray(List<Color> colors) → BufferAttribute<TypedDataList>
Copy the Color array given here into array.
inherited
copyVector2sArray(List<Vector2> vectors) → BufferAttribute<TypedDataList>
Copy the Vector2 array given here into array.
inherited
copyVector3sArray(List<Vector3> vectors) → BufferAttribute<TypedDataList>
Copy the Vector3 array given here into array.
inherited
copyVector4sArray(List<Vector4> vectors) → BufferAttribute<TypedDataList>
Copy the Vector4 array given here into array.
inherited
dispose() → void
inherited
getAt(int index) → double?
inherited
getComponent(int index, int component) → double
Returns the given component of the vector at the given index.
getFrom(String key, int index) → num?
inherited
getW(int index) → double
Returns the w component of the item at the given index.
override
getX(int index) → double
Returns the x component of the item at the given index.
override
getY(int index) → double
Returns the y component of the item at the given index.
override
getZ(int index) → double
Returns the z component of the item at the given index.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUpload(void callback()?) → BufferAttribute<TypedDataList>
inherited
set(dynamic value, {int offset = 0}) → BufferAttribute<TypedDataList>
value - an List or [TypedData from which to copy values.
inherited
setComponent(int index, int component, double value) → InterleavedBufferAttribute
Sets the given value to the given component of the vector at the given index.
setFrom(String key, int index, num number) → void
inherited
setUsage(int value) → BufferAttribute<TypedDataList>
inherited
setW(int index, double w) → InterleavedBufferAttribute
Sets the w component of the vector at the given index.
override
setX(int index, num x) → InterleavedBufferAttribute
Sets the x component of the item at the given index.
override
setXY(int index, double x, double y) → InterleavedBufferAttribute
Sets the x and y components of the item at the given index.
override
setXYZ(int index, double x, double y, double z) → InterleavedBufferAttribute
Sets the x, y and z components of the item at the given index.
override
setXYZW(int index, num x, num y, num z, num w) → InterleavedBufferAttribute
Sets the x, y, z and w components of the item at the given index.
override
setY(int index, num y) → InterleavedBufferAttribute
Sets the y component of the item at the given index.
override
setZ(int index, num z) → InterleavedBufferAttribute
Sets the z component of the item at the given index.
override
toJson([InterleavedBuffer? data]) → Map<String, Object>
override
toString() → String
A string representation of this object.
inherited
transformDirection(Matrix4 m) → InterleavedBufferAttribute
Applies matrix m to every Vector3 element of this InterleavedBufferAttribute, interpreting the elements as a direction vectors.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited