MathUtils class

Constructors

MathUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

deg2rad ↔ double
getter/setter pair
maxSafeInteger ↔ int
getter/setter pair
rad2deg ↔ double
getter/setter pair

Static Methods

ceilPowerOfTwo<T extends num>(T value) → double
clamp<T extends num>(T value, T min, T max) → T
degToRad(double val) → double
denormalize(num value, TypedData array) → double
Denormalizes the given value according to the given typed array.
floorPowerOfTwo<T extends num>(T value) → double
fromHalfFloat(num value) → dynamic
generateUUID() → String
isPowerOfTwo(int value) → bool
listGetMaxValue<T extends num>(List<T> array) → T?
log2(num x) → double
mapLinear<T extends num>(T x, T a1, T a2, T b1, T b2) → num
normalize(num value, TypedData array) → double
Normalizes the given value according to the given typed array.
radToDeg(double val) → double
toHalfFloat(num val) → int

Constants

epsilon → const double