three_js_math library

Classes

BaseBufferAttribute<TData extends TypedDataList>
BoundingBox
Represents an axis-aligned bounding box (AABB) in 3D space.
BoundingSphere
A sphere defined by a center and radius.
BufferAttribute<TData extends TypedDataList>
This class stores data for an attribute (such as vertex positions, face indices, normals, colors, UVs, and any custom attributes ) associated with a BufferGeometry, which allows for more efficient passing of data to the GPU. See that page for details and a usage example. When working with vector-like data, the .fromBufferAttribute( attribute, index ) helper methods on Vector2, Vector3, Vector4, and Color classes may be helpful.
Color
ColorManagement
Euler
A class representing Euler Angles.
Float16BufferAttribute
Float32BufferAttribute
Float64BufferAttribute
GLBufferAttribute
This buffer attribute class does not construct a VBO. Instead, it uses whatever VBO is passed in constructor and can later be altered via the buffer property.
InstancedBufferAttribute
An instanced version of BufferAttribute.
InstancedInterleavedBuffer
An instanced version of InterleavedBuffer.
Int16BufferAttribute
Int32BufferAttribute
Int8BufferAttribute
InterleavedBuffer
Interleaved means that multiple attributes, possibly of different types, (e.g., position, normal, uv, color) are packed into a single array buffer.
InterleavedBufferAttribute
Line3
A geometric line segment represented by a start and end point.
MathUtils
Matrix2
Represents a 2x2 matrix.
Matrix3
A class representing a 3x3 matrix.
Matrix4
Mouse
Plane
Quaternion
Ranges
Ray
SphericalHarmonics3
Primary reference: https://graphics.stanford.edu/papers/envmap/envmap.pdf
Touch
Triangle
Uint16BufferAttribute
Uint32BufferAttribute
Uint8BufferAttribute
Uint8ClampedBufferAttribute
Vector
Vector2
Vector3
Vector4

Enums

Attribute
List of all the attributes used in threejs
ColorSpace
RotationOrders

Constants

ACESFilmicToneMapping → const int
AddEquation → const int
AdditiveAnimationBlendMode → const int
AdditiveBlending → const int
AddOperation → const int
AgXToneMapping → const int
AlphaFormat → const int
AlwaysCompare → const int
AlwaysDepth → const int
AlwaysStencilFunc → const int
AttachedBindMode → const String
BackSide → const int
BasicDepthPacking → const int
BasicShadowMap → const int
ByteType → const int
CineonToneMapping → const int
ClampToEdgeWrapping → const int
ConstantAlphaFactor → const int
ConstantColorFactor → const int
CubeReflectionMapping → const int
CubeRefractionMapping → const int
CubeUVReflectionMapping → const int
CullFaceBack → const int
CullFaceFront → const int
CullFaceFrontBack → const int
CullFaceNone → const int
CustomBlending → const int
CustomToneMapping → const int
DecrementStencilOp → const int
DecrementWrapStencilOp → const int
DepthFormat → const int
DepthStencilFormat → const int
DetachedBindMode → const String
DisplayP3ColorSpace → const String
DoubleSide → const int
DstAlphaFactor → const int
DstColorFactor → const int
DynamicCopyUsage → const int
DynamicDrawUsage → const int
DynamicReadUsage → const int
EqualCompare → const int
EqualDepth → const int
EqualStencilFunc → const int
EquirectangularReflectionMapping → const int
EquirectangularRefractionMapping → const int
FlatShading → const bool
FloatType → const int
FrontSide → const int
GammaEncoding → const int
GLSL1 → const String
GLSL3 → const String
GreaterCompare → const int
GreaterDepth → const int
GreaterEqualCompare → const int
GreaterEqualDepth → const int
GreaterEqualStencilFunc → const int
GreaterStencilFunc → const int
HalfFloatType → const int
IncrementStencilOp → const int
IncrementWrapStencilOp → const int
InterpolateDiscrete → const int
InterpolateLinear → const int
InterpolateSmooth → const int
IntType → const int
InvertStencilOp → const int
KeepStencilOp → const int
LessCompare → const int
LessDepth → const int
LessEqualCompare → const int
LessEqualDepth → const int
LessEqualStencilFunc → const int
LessStencilFunc → const int
LinearDisplayP3ColorSpace → const String
LinearEncoding → const int
LinearFilter → const int
LinearMipMapLinearFilter → const int
LinearMipmapLinearFilter → const int
LinearMipMapNearestFilter → const int
LinearMipmapNearestFilter → const int
LinearSRGBColorSpace → const String
LinearToneMapping → const int
LinearTransfer → const String
LogLuvEncoding → const int
LoopOnce → const int
LoopPingPong → const int
LoopRepeat → const int
LuminanceAlphaFormat → const int
LuminanceFormat → const int
MAX_SAFE_INTEGER → const int
MaxEquation → const int
MinEquation → const int
MirroredRepeatWrapping → const int
MixOperation → const int
MultiplyBlending → const int
MultiplyOperation → const int
NearestFilter → const int
NearestMipMapLinearFilter → const int
NearestMipmapLinearFilter → const int
NearestMipMapNearestFilter → const int
NearestMipmapNearestFilter → const int
NeutralToneMapping → const int
NeverCompare → const int
NeverDepth → const int
NeverStencilFunc → const int
NoBlending → const int
NoColorSpace → const String
NormalAnimationBlendMode → const int
NormalBlending → const int
NotEqualCompare → const int
NotEqualDepth → const int
NotEqualStencilFunc → const int
NoToneMapping → const int
ObjectSpaceNormalMap → const int
OneFactor → const int
OneMinusConstantAlphaFactor → const int
OneMinusConstantColorFactor → const int
OneMinusDstAlphaFactor → const int
OneMinusDstColorFactor → const int
OneMinusSrcAlphaFactor → const int
OneMinusSrcColorFactor → const int
P3Primaries → const String
PCFShadowMap → const int
PCFSoftShadowMap → const int
Rec709Primaries → const String
RED_GREEN_RGTC2_Format → const int
RED_RGTC1_Format → const int
RedFormat → const int
RedIntegerFormat → const int
ReinhardToneMapping → const int
RepeatWrapping → const int
ReplaceStencilOp → const int
ReverseSubtractEquation → const int
REVISION → const String
RGB_BPTC_SIGNED_Format → const int
RGB_BPTC_UNSIGNED_Format → const int
RGB_ETC1_Format → const int
RGB_ETC2_Format → const int
RGB_PVRTC_2BPPV1_Format → const int
RGB_PVRTC_4BPPV1_Format → const int
RGB_S3TC_DXT1_Format → const int
RGBA_ASTC_10x10_Format → const int
RGBA_ASTC_10x5_Format → const int
RGBA_ASTC_10x6_Format → const int
RGBA_ASTC_10x8_Format → const int
RGBA_ASTC_12x10_Format → const int
RGBA_ASTC_12x12_Format → const int
RGBA_ASTC_4x4_Format → const int
RGBA_ASTC_5x4_Format → const int
RGBA_ASTC_5x5_Format → const int
RGBA_ASTC_6x5_Format → const int
RGBA_ASTC_6x6_Format → const int
RGBA_ASTC_8x5_Format → const int
RGBA_ASTC_8x6_Format → const int
RGBA_ASTC_8x8_Format → const int
RGBA_BPTC_Format → const int
RGBA_ETC2_EAC_Format → const int
RGBA_PVRTC_2BPPV1_Format → const int
RGBA_PVRTC_4BPPV1_Format → const int
RGBA_S3TC_DXT1_Format → const int
RGBA_S3TC_DXT3_Format → const int
RGBA_S3TC_DXT5_Format → const int
RGBADepthPacking → const int
RGBAFormat → const int
RGBAIntegerFormat → const int
RGBDEncoding → const int
RGBEEncoding → const int
RGBEFormat → const int
RGBFormat → const int
RGBIntegerFormat → const int
RGBM16Encoding → const int
RGBM7Encoding → const int
RGFormat → const int
RGIntegerFormat → const int
ShortType → const int
SIGNED_RED_GREEN_RGTC2_Format → const int
SIGNED_RED_RGTC1_Format → const int
SmoothShading → const int
SrcAlphaFactor → const int
SrcAlphaSaturateFactor → const int
SrcColorFactor → const int
SRGBAFormat → const int
SRGBColorSpace → const String
sRGBEncoding → const int
SRGBFormat → const int
SRGBTransfer → const String
StaticCopyUsage → const int
StaticDrawUsage → const int
StaticReadUsage → const int
StreamCopyUsage → const int
StreamDrawUsage → const int
StreamReadUsage → const int
SubtractEquation → const int
SubtractiveBlending → const int
TangentSpaceNormalMap → const int
TriangleFanDrawMode → const int
TrianglesDrawMode → const int
TriangleStripDrawMode → const int
UnsignedByteType → const int
UnsignedInt248Type → const int
UnsignedInt5999Type → const int
UnsignedIntType → const int
UnsignedShort4444Type → const int
UnsignedShort5551Type → const int
UnsignedShort565Type → const int
UnsignedShortType → const int
UVMapping → const int
VSMShadowMap → const int
WebGLCoordinateSystem → const int
WebGPUCoordinateSystem → const int
WrapAroundEnding → const int
ZeroCurvatureEnding → const int
ZeroFactor → const int
ZeroSlopeEnding → const int
ZeroStencilOp → const int

Properties

fn Map<ColorSpace, dynamic>
final
ldp32lsrgb Matrix3
final
lsrgb2ldp3 Matrix3
final