Vector class abstract

Implementers

Constructors

Vector([double x = 0, double y = 0])
Vector.copy(Vector v)
Vector.zero()

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → double
no setter
length2 → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage ↔ Float32List
getter/setter pair
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair

Methods

add(Vector a) → Vector
addScalar(double s) → Vector
addScaled(Vector v, double s) → Vector
applyMatrix3(Matrix3 m) → Vector
ceil() → Vector
clampLength<T extends num>(T min, T max) → Vector
clampScalar(double minVal, double maxVal) → Vector
clone() → Vector
copyFromArray(List<double> array, [int offset = 0]) → Vector
copyFromUnknown(dynamic array, [int offset = 0]) → Vector
copyIntoArray([List<double> array, int offset = 0]) → List<double>
copyIntoList(Float32List array, [int offset = 0]) → Float32List
distanceTo(Vector v) → double
distanceToSquared(Vector v) → double
divideScalar(double scalar) → Vector
dot(Vector v) → double
equals(Vector v) → bool
floor() → Vector
fromArray(List<num> array, [int offset = 0]) → Vector
fromBuffer(BufferAttribute<TypedDataList> attribute, int index) → Vector
getComponent(int index) → num
manhattanLength() → double
negate() → Vector
normalize() → Vector
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
random() → Vector
round() → Vector
roundToZero() → Vector
scale(double scalar) → Vector
setFrom(Vector v) → Vector
setLength(double length) → Vector
setScalar(double scalar) → Vector
setValues(double x, double y) → Vector
sub(Vector a) → Vector
subScalar(double s) → Vector
toJson() → Map<String, dynamic>
toList() → List<double>
toNumArray(List<num> array, [int offset = 0]) → List<num>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → double
operator []=(int index, double value) → void